@@ -205,10 +205,11 @@ main (int argc, char **argv)
 	if (args.concise)
 	  {
 	    file_name = EXT_ARRAY_GET(args.file, char *, i);
-	    ifile_concise_ratings(file_name, stdout, ratings, &idata);
+	    ifile_concise_ratings(file_name, stdout, ratings, &idata,
+				  args.thresh);
 	  }
 	else
-	  ifile_print_ratings(stdout, ratings, &idata);
+	  ifile_print_ratings(stdout, ratings, &idata, args.thresh);
 
 	ifile_free_categories(ratings,&idata);
 	ifile_add_db(args.loocv_folder, message, &idata, args.create_folder);
@@ -227,10 +228,11 @@ main (int argc, char **argv)
 	    if (args.concise)
 	      {
 		file_name = EXT_ARRAY_GET(args.file, char *, i);
-		ifile_concise_ratings(file_name, stdout, ratings, &idata);
+		ifile_concise_ratings(file_name, stdout, ratings, &idata,
+				      args.thresh);
 	      }
 	    else
-	      ifile_print_ratings(stdout, ratings, &idata);
+	      ifile_print_ratings(stdout, ratings, &idata, args.thresh);
 
 	    if (args.query_insert)
 	      ifile_add_db(ratings[0].category, message, &idata, args.create_folder);
