@@ -35,10 +35,10 @@
 #include "hash_table.h"
 
 
-#define IFILE_VERSION "ifile 1.3.3"
+#define IFILE_VERSION "ifile 1.3.4"
 #define IFILE_MAJOR_VERSION 1
 #define IFILE_MINOR_VERSION 3
-#define IFILE_TRIFLING_VERSION 3
+#define IFILE_TRIFLING_VERSION 4
 
 #define FALSE 0
 #define TRUE 1
@@ -138,7 +138,7 @@ typedef struct _ifile_db {
 typedef struct _arguments
 {
   extendable_array file;		/* [FILE...] */
-  int num_files;
+  int num_files, thresh;
   int query, query_insert, concise;
   int stemming, stoplist, lexer;
   int skip_header, tag_headers, keep_infrequent, verbosity;
@@ -176,9 +176,9 @@ void ifile_bitify_document(htable * message);
 category_rating * ifile_rate_categories (htable * message, ifile_db * idata);
 void ifile_free_categories(category_rating *cr, ifile_db *idata);
 void ifile_concise_ratings (char * path, FILE * FP, category_rating * ratings,
-			  ifile_db * idata);
+			  ifile_db * idata, int thresh);
 void ifile_print_ratings (FILE * FP, category_rating * ratings,
-			  ifile_db * idata);
+			  ifile_db * idata, int thresh);
 
 /* database functions */
 void ifile_db_init(ifile_db * idata);
