@@ -31,6 +31,11 @@ static struct argp_option options[] = {
   {"concise",       'c', 0,        0,
    "Equivalent of \"ifile -v 0 | head -1 | cut -f1 -d' '\".  "
    "Must be used with -q or -Q."},
+  {"threshold", 'T', "THRESH", 0,
+   "With more than 1 folder, for top 2 folders (f0,f1) with ratings (r0,r1), "
+   "  if THRESH > 0 then with -q print also 'diff[f0,f1](%) x.xx' and if "
+   "  R=(r0-r1)/(r0+r1), R*1000 < THRESH, then "
+   "  with -c -q print 'f0,f1' instead of jusrt 'f0'; disabled if THRESH=0."},
   {"query",       'q', 0,        0,
    "Output rating scores for each of FILES"},
   {"query-insert",'Q', 0,        0,
@@ -121,6 +126,16 @@ parse_opt (int key, char *arg, struct argp_state *state)
       args->read_message = TRUE;
       args->read_db = TRUE;
       break;
+    case 'T':
+      ifile_verbosify(ifile_verbose, "--threshold=%s\n", arg);
+      args->thresh = arg ? atoi(arg) : 0;
+      if (args->thresh < 0 || args->thresh > 200)
+	{
+	  ifile_verbosify(ifile_verbose, "Invalid threshold: %d\n",
+			  args->thresh);
+	  args->thresh = 0;
+	}
+       break;
     case 'Q':
       ifile_verbosify(ifile_verbose, "--query-insert\n");
       args->query = TRUE;
